@@ -8,7 +8,7 @@ use Code::TidyAll::Util
     qw(abs2rel basename can_load dirname dump_one_line mkpath read_dir rel2abs tempdir_simple uniq);
 use Code::TidyAll::Result;
 use Date::Format;
-use Digest::SHA1 qw(sha1_hex);
+use Digest::SHA qw(sha1_hex);
 use File::Find qw(find);
 use File::Slurp::Tiny qw(read_file write_file);
 use File::Zglob;
@@ -19,7 +19,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -534,7 +534,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -725,7 +725,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Grimes Olaf Alders Pedro Melo timgimyee
+=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Grimes Olaf Alders Pedro Melo Sergey Romanov timgimyee
 
 =over 4
 
@@ -763,6 +763,10 @@ Pedro Melo <melo@simplicidade.org>
 
 =item *
 
+Sergey Romanov <sromanov-dev@yandex.ru>
+
+=item *
+
 timgimyee <tim.gim.yee@gmail.com>
 
 =back
